pub enum RawPayloadKind {
InferenceRequest,
InferenceResponse,
CompactionRequest,
CompactionCheckpoint,
CompactionResponse,
ToolInvocation,
ToolResult,
ToolRuntimeEvent,
TerminalRuntimeEvent,
ProtocolEvent,
SessionMetadata,
AgentResult,
}Expand description
Coarse role labels for raw payload files. Coarse role of a raw payload.
Variants
InferenceRequest
InferenceResponse
Full upstream inference response or non-delta response stream summary.
CompactionRequest
CompactionCheckpoint
Trace-only checkpoint captured when processed replacement history is installed.
CompactionResponse
ToolInvocation
ToolResult
ToolRuntimeEvent
Raw runtime/protocol observation for an executing tool.
TerminalRuntimeEvent
Raw terminal runtime event or stream shard.
ProtocolEvent
SessionMetadata
One-shot metadata captured when a Codex session/thread starts.
AgentResult
Runtime notification payload carried when a child agent reports back to its parent.