pub enum RawToolCallRequester {
Model,
CodeCell {
runtime_cell_id: String,
},
}Expand description
Runtime requester observed before semantic reduction. Runtime requester as observed at the raw tool boundary.
This intentionally uses runtime-local identifiers. The reducer is the only
place that maps these handles to graph identities such as CodeCellId.
Variants