ConversationBody

Struct ConversationBody 

pub struct ConversationBody {
    pub parts: Vec<ConversationPart>,
}
Public reduced trace model returned by replay. Ordered content parts for a reduced conversation item.

Fields

parts: Vec<ConversationPart>

Renderable model-visible parts. Raw payload refs are used when the bytes are too large or too structured for the normal conversation path.