pub struct ExecutionWindow {
pub started_at_unix_ms: i64,
pub started_seq: RawEventSeq,
pub ended_at_unix_ms: Option<i64>,
pub ended_seq: Option<RawEventSeq>,
pub status: ExecutionStatus,
}Expand description
Public reduced trace model returned by replay. Runtime interval for a typed trace object.
Wall-clock timestamps are for display and latency. Sequence numbers are the causal ordering primitive and should be used to pair observations or break same-millisecond ties.
Fields
started_at_unix_ms: i64started_seq: RawEventSeqended_at_unix_ms: Option<i64>ended_seq: Option<RawEventSeq>status: ExecutionStatusTrait Implementations
Sourceimpl Clone for ExecutionWindow
impl Clone for ExecutionWindow
Sourcefn clone(&self) -> ExecutionWindow
fn clone(&self) -> ExecutionWindow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExecutionWindow
impl Debug for ExecutionWindow
Sourceimpl<'de> Deserialize<'de> for ExecutionWindow
impl<'de> Deserialize<'de> for ExecutionWindow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExecutionWindow
Sourceimpl PartialEq for ExecutionWindow
impl PartialEq for ExecutionWindow
Sourceimpl Serialize for ExecutionWindow
impl Serialize for ExecutionWindow
impl StructuralPartialEq for ExecutionWindow